This package provide tools for univariate and multivariate generalized linear models with model averaging and null model technique (Nakamura et al. 2015).
maglmModel averaging for GLM based on information theory.
mamglmModel averaging for multivariate GLM based on information theory.
ses.maglmStandardized effect size of relative importance values for model averaging GLM.
ses.mamglmStandardized effect size of relative importance values for model averaging mutlivariate GLM.
Burnham, K.P. & Anderson, D.R. (2002) Model selection and multi-model inference: a practical information-theoretic approach. Springer Verlag, New York.
Nakamura, A., C. J. Burwell, C. L. Lambkin, M. Katabuchi, A. McDougall, R. J. Raven, and V. J. Neldner. (2015) The role of human disturbance in island biogeography of arthropods and plants: an information theoretic approach. Journal of Biogeography 42:1406-1417.
Useful links: